Exception: MailSmtp::PipeliningNotSupported
- Defined in:
- lib/mailsmtp/errors.rb
Overview
500 — a second command arrived pipelined ahead of its reply, which we don't support
500 — a second command arrived pipelined ahead of its reply, which we don't support